# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_monitoring.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_monitoring.proto',
  package='Ydb.Monitoring',
  syntax='proto3',
  serialized_options=b'\n\031tech.ydb.proto.monitoringB\020MonitoringProtosZ=github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Monitoring\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bprotos/ydb_monitoring.proto\x12\x0eYdb.Monitoring\x1a\x1aprotos/ydb_operation.proto\"g\n\nStatusFlag\"Y\n\x06Status\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04GREY\x10\x01\x12\t\n\x05GREEN\x10\x02\x12\x08\n\x04\x42LUE\x10\x03\x12\n\n\x06YELLOW\x10\x04\x12\n\n\x06ORANGE\x10\x05\x12\x07\n\x03RED\x10\x06\"\xbe\x01\n\x10SelfCheckRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x15return_verbose_status\x18\x02 \x01(\x08\x12\x39\n\x0eminimum_status\x18\x03 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x15\n\rmaximum_level\x18\x04 \x01(\r\"A\n\x11SelfCheckResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"M\n\x10NodeCheckRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11NodeCheckResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"g\n\tSelfCheck\"Z\n\x06Result\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04GOOD\x10\x01\x12\x0c\n\x08\x44\x45GRADED\x10\x02\x12\x18\n\x14MAINTENANCE_REQUIRED\x10\x03\x12\r\n\tEMERGENCY\x10\x04\"T\n\x12StoragePDiskStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\"\xc0\x01\n\x12StorageVDiskStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x37\n\x0cvdisk_status\x18\x03 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x31\n\x05pdisk\x18\x04 \x01(\x0b\x32\".Ydb.Monitoring.StoragePDiskStatus\"\x88\x01\n\x12StorageGroupStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x32\n\x06vdisks\x18\x03 \x03(\x0b\x32\".Ydb.Monitoring.StorageVDiskStatus\"\x87\x01\n\x11StoragePoolStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x32\n\x06groups\x18\x03 \x03(\x0b\x32\".Ydb.Monitoring.StorageGroupStatus\"u\n\rStorageStatus\x12\x32\n\x07overall\x18\x01 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x30\n\x05pools\x18\x02 \x03(\x0b\x32!.Ydb.Monitoring.StoragePoolStatus\"\x81\x01\n\x13\x43omputeTabletStatus\x12\x32\n\x07overall\x18\x01 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\r\x12\n\n\x02id\x18\x05 \x03(\t\"c\n\x10ThreadPoolStatus\x12\x32\n\x07overall\x18\x01 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05usage\x18\x03 \x01(\x02\"d\n\x11LoadAverageStatus\x12\x32\n\x07overall\x18\x01 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x0c\n\x04load\x18\x02 \x01(\x02\x12\r\n\x05\x63ores\x18\x03 \x01(\r\"\xeb\x01\n\x11\x43omputeNodeStatus\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x34\n\x07tablets\x18\x03 \x03(\x0b\x32#.Ydb.Monitoring.ComputeTabletStatus\x12/\n\x05pools\x18\x04 \x03(\x0b\x32 .Ydb.Monitoring.ThreadPoolStatus\x12/\n\x04load\x18\x05 \x01(\x0b\x32!.Ydb.Monitoring.LoadAverageStatus\"\xab\x01\n\rComputeStatus\x12\x32\n\x07overall\x18\x01 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x30\n\x05nodes\x18\x02 \x03(\x0b\x32!.Ydb.Monitoring.ComputeNodeStatus\x12\x34\n\x07tablets\x18\x03 \x03(\x0b\x32#.Ydb.Monitoring.ComputeTabletStatus\"6\n\x0cLocationNode\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\"0\n\x14LocationStoragePDisk\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"W\n\x14LocationStorageVDisk\x12\n\n\x02id\x18\x01 \x03(\t\x12\x33\n\x05pdisk\x18\x02 \x03(\x0b\x32$.Ydb.Monitoring.LocationStoragePDisk\"W\n\x14LocationStorageGroup\x12\n\n\x02id\x18\x01 \x03(\t\x12\x33\n\x05vdisk\x18\x02 \x01(\x0b\x32$.Ydb.Monitoring.LocationStorageVDisk\"X\n\x13LocationStoragePool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x33\n\x05group\x18\x02 \x01(\x0b\x32$.Ydb.Monitoring.LocationStorageGroup\"p\n\x0fLocationStorage\x12*\n\x04node\x18\x01 \x01(\x0b\x32\x1c.Ydb.Monitoring.LocationNode\x12\x31\n\x04pool\x18\x02 \x01(\x0b\x32#.Ydb.Monitoring.LocationStoragePool\"#\n\x13LocationComputePool\x12\x0c\n\x04name\x18\x01 \x01(\t\"@\n\x15LocationComputeTablet\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x03(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\r\"\xa7\x01\n\x0fLocationCompute\x12*\n\x04node\x18\x01 \x01(\x0b\x32\x1c.Ydb.Monitoring.LocationNode\x12\x31\n\x04pool\x18\x02 \x01(\x0b\x32#.Ydb.Monitoring.LocationComputePool\x12\x35\n\x06tablet\x18\x03 \x01(\x0b\x32%.Ydb.Monitoring.LocationComputeTablet\" \n\x10LocationDatabase\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xa2\x01\n\x08Location\x12\x30\n\x07storage\x18\x01 \x01(\x0b\x32\x1f.Ydb.Monitoring.LocationStorage\x12\x30\n\x07\x63ompute\x18\x02 \x01(\x0b\x32\x1f.Ydb.Monitoring.LocationCompute\x12\x32\n\x08\x64\x61tabase\x18\x03 \x01(\x0b\x32 .Ydb.Monitoring.LocationDatabase\"\xd2\x01\n\x08IssueLog\x12\n\n\x02id\x18\x01 \x01(\t\x12\x31\n\x06status\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12\x0f\n\x07message\x18\x03 \x01(\t\x12*\n\x08location\x18\x04 \x01(\x0b\x32\x18.Ydb.Monitoring.Location\x12\x0e\n\x06reason\x18\x05 \x03(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\r\n\x05level\x18\x07 \x01(\r\x12\x0e\n\x06listed\x18\x08 \x01(\r\x12\r\n\x05\x63ount\x18\t \x01(\r\"\xb2\x01\n\x0e\x44\x61tabaseStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x07overall\x18\x02 \x01(\x0e\x32!.Ydb.Monitoring.StatusFlag.Status\x12.\n\x07storage\x18\x03 \x01(\x0b\x32\x1d.Ydb.Monitoring.StorageStatus\x12.\n\x07\x63ompute\x18\x04 \x01(\x0b\x32\x1d.Ydb.Monitoring.ComputeStatus\"\xb4\x01\n\x0fSelfCheckResult\x12;\n\x11self_check_result\x18\x01 \x01(\x0e\x32 .Ydb.Monitoring.SelfCheck.Result\x12+\n\tissue_log\x18\x02 \x03(\x0b\x32\x18.Ydb.Monitoring.IssueLog\x12\x37\n\x0f\x64\x61tabase_status\x18\x03 \x03(\x0b\x32\x1e.Ydb.Monitoring.DatabaseStatusBo\n\x19tech.ydb.proto.monitoringB\x10MonitoringProtosZ=github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Monitoring\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[protos_dot_ydb__operation__pb2.DESCRIPTOR,])



_STATUSFLAG_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='Ydb.Monitoring.StatusFlag.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLUE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORANGE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=89,
  serialized_end=178,
)
_sym_db.RegisterEnumDescriptor(_STATUSFLAG_STATUS)

_SELFCHECK_RESULT = _descriptor.EnumDescriptor(
  name='Result',
  full_name='Ydb.Monitoring.SelfCheck.Result',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GOOD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEGRADED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAINTENANCE_REQUIRED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMERGENCY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=599,
  serialized_end=689,
)
_sym_db.RegisterEnumDescriptor(_SELFCHECK_RESULT)


_STATUSFLAG = _descriptor.Descriptor(
  name='StatusFlag',
  full_name='Ydb.Monitoring.StatusFlag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATUSFLAG_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=75,
  serialized_end=178,
)


_SELFCHECKREQUEST = _descriptor.Descriptor(
  name='SelfCheckRequest',
  full_name='Ydb.Monitoring.SelfCheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Monitoring.SelfCheckRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='return_verbose_status', full_name='Ydb.Monitoring.SelfCheckRequest.return_verbose_status', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minimum_status', full_name='Ydb.Monitoring.SelfCheckRequest.minimum_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maximum_level', full_name='Ydb.Monitoring.SelfCheckRequest.maximum_level', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=371,
)


_SELFCHECKRESPONSE = _descriptor.Descriptor(
  name='SelfCheckResponse',
  full_name='Ydb.Monitoring.SelfCheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Monitoring.SelfCheckResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=438,
)


_NODECHECKREQUEST = _descriptor.Descriptor(
  name='NodeCheckRequest',
  full_name='Ydb.Monitoring.NodeCheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Monitoring.NodeCheckRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=517,
)


_NODECHECKRESPONSE = _descriptor.Descriptor(
  name='NodeCheckResponse',
  full_name='Ydb.Monitoring.NodeCheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='Ydb.Monitoring.NodeCheckResponse.operation', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=584,
)


_SELFCHECK = _descriptor.Descriptor(
  name='SelfCheck',
  full_name='Ydb.Monitoring.SelfCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SELFCHECK_RESULT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=689,
)


_STORAGEPDISKSTATUS = _descriptor.Descriptor(
  name='StoragePDiskStatus',
  full_name='Ydb.Monitoring.StoragePDiskStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.StoragePDiskStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.StoragePDiskStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=775,
)


_STORAGEVDISKSTATUS = _descriptor.Descriptor(
  name='StorageVDiskStatus',
  full_name='Ydb.Monitoring.StorageVDiskStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.StorageVDiskStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.StorageVDiskStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vdisk_status', full_name='Ydb.Monitoring.StorageVDiskStatus.vdisk_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdisk', full_name='Ydb.Monitoring.StorageVDiskStatus.pdisk', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=970,
)


_STORAGEGROUPSTATUS = _descriptor.Descriptor(
  name='StorageGroupStatus',
  full_name='Ydb.Monitoring.StorageGroupStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.StorageGroupStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.StorageGroupStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vdisks', full_name='Ydb.Monitoring.StorageGroupStatus.vdisks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=973,
  serialized_end=1109,
)


_STORAGEPOOLSTATUS = _descriptor.Descriptor(
  name='StoragePoolStatus',
  full_name='Ydb.Monitoring.StoragePoolStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.StoragePoolStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.StoragePoolStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='groups', full_name='Ydb.Monitoring.StoragePoolStatus.groups', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1247,
)


_STORAGESTATUS = _descriptor.Descriptor(
  name='StorageStatus',
  full_name='Ydb.Monitoring.StorageStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.StorageStatus.overall', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pools', full_name='Ydb.Monitoring.StorageStatus.pools', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1249,
  serialized_end=1366,
)


_COMPUTETABLETSTATUS = _descriptor.Descriptor(
  name='ComputeTabletStatus',
  full_name='Ydb.Monitoring.ComputeTabletStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.ComputeTabletStatus.overall', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Ydb.Monitoring.ComputeTabletStatus.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='Ydb.Monitoring.ComputeTabletStatus.state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Monitoring.ComputeTabletStatus.count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.ComputeTabletStatus.id', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1369,
  serialized_end=1498,
)


_THREADPOOLSTATUS = _descriptor.Descriptor(
  name='ThreadPoolStatus',
  full_name='Ydb.Monitoring.ThreadPoolStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.ThreadPoolStatus.overall', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Monitoring.ThreadPoolStatus.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='Ydb.Monitoring.ThreadPoolStatus.usage', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1500,
  serialized_end=1599,
)


_LOADAVERAGESTATUS = _descriptor.Descriptor(
  name='LoadAverageStatus',
  full_name='Ydb.Monitoring.LoadAverageStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.LoadAverageStatus.overall', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load', full_name='Ydb.Monitoring.LoadAverageStatus.load', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cores', full_name='Ydb.Monitoring.LoadAverageStatus.cores', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1601,
  serialized_end=1701,
)


_COMPUTENODESTATUS = _descriptor.Descriptor(
  name='ComputeNodeStatus',
  full_name='Ydb.Monitoring.ComputeNodeStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.ComputeNodeStatus.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.ComputeNodeStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tablets', full_name='Ydb.Monitoring.ComputeNodeStatus.tablets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pools', full_name='Ydb.Monitoring.ComputeNodeStatus.pools', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load', full_name='Ydb.Monitoring.ComputeNodeStatus.load', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1704,
  serialized_end=1939,
)


_COMPUTESTATUS = _descriptor.Descriptor(
  name='ComputeStatus',
  full_name='Ydb.Monitoring.ComputeStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.ComputeStatus.overall', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodes', full_name='Ydb.Monitoring.ComputeStatus.nodes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tablets', full_name='Ydb.Monitoring.ComputeStatus.tablets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1942,
  serialized_end=2113,
)


_LOCATIONNODE = _descriptor.Descriptor(
  name='LocationNode',
  full_name='Ydb.Monitoring.LocationNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.LocationNode.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='Ydb.Monitoring.LocationNode.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='Ydb.Monitoring.LocationNode.port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2115,
  serialized_end=2169,
)


_LOCATIONSTORAGEPDISK = _descriptor.Descriptor(
  name='LocationStoragePDisk',
  full_name='Ydb.Monitoring.LocationStoragePDisk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.LocationStoragePDisk.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='Ydb.Monitoring.LocationStoragePDisk.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2171,
  serialized_end=2219,
)


_LOCATIONSTORAGEVDISK = _descriptor.Descriptor(
  name='LocationStorageVDisk',
  full_name='Ydb.Monitoring.LocationStorageVDisk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.LocationStorageVDisk.id', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pdisk', full_name='Ydb.Monitoring.LocationStorageVDisk.pdisk', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2221,
  serialized_end=2308,
)


_LOCATIONSTORAGEGROUP = _descriptor.Descriptor(
  name='LocationStorageGroup',
  full_name='Ydb.Monitoring.LocationStorageGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.LocationStorageGroup.id', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vdisk', full_name='Ydb.Monitoring.LocationStorageGroup.vdisk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2310,
  serialized_end=2397,
)


_LOCATIONSTORAGEPOOL = _descriptor.Descriptor(
  name='LocationStoragePool',
  full_name='Ydb.Monitoring.LocationStoragePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Monitoring.LocationStoragePool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='Ydb.Monitoring.LocationStoragePool.group', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2399,
  serialized_end=2487,
)


_LOCATIONSTORAGE = _descriptor.Descriptor(
  name='LocationStorage',
  full_name='Ydb.Monitoring.LocationStorage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='Ydb.Monitoring.LocationStorage.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool', full_name='Ydb.Monitoring.LocationStorage.pool', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2489,
  serialized_end=2601,
)


_LOCATIONCOMPUTEPOOL = _descriptor.Descriptor(
  name='LocationComputePool',
  full_name='Ydb.Monitoring.LocationComputePool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Monitoring.LocationComputePool.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2603,
  serialized_end=2638,
)


_LOCATIONCOMPUTETABLET = _descriptor.Descriptor(
  name='LocationComputeTablet',
  full_name='Ydb.Monitoring.LocationComputeTablet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='Ydb.Monitoring.LocationComputeTablet.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.LocationComputeTablet.id', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Monitoring.LocationComputeTablet.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2640,
  serialized_end=2704,
)


_LOCATIONCOMPUTE = _descriptor.Descriptor(
  name='LocationCompute',
  full_name='Ydb.Monitoring.LocationCompute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='Ydb.Monitoring.LocationCompute.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool', full_name='Ydb.Monitoring.LocationCompute.pool', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tablet', full_name='Ydb.Monitoring.LocationCompute.tablet', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2707,
  serialized_end=2874,
)


_LOCATIONDATABASE = _descriptor.Descriptor(
  name='LocationDatabase',
  full_name='Ydb.Monitoring.LocationDatabase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Monitoring.LocationDatabase.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2876,
  serialized_end=2908,
)


_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='Ydb.Monitoring.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='Ydb.Monitoring.Location.storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compute', full_name='Ydb.Monitoring.Location.compute', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database', full_name='Ydb.Monitoring.Location.database', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2911,
  serialized_end=3073,
)


_ISSUELOG = _descriptor.Descriptor(
  name='IssueLog',
  full_name='Ydb.Monitoring.IssueLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Monitoring.IssueLog.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Monitoring.IssueLog.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='Ydb.Monitoring.IssueLog.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='Ydb.Monitoring.IssueLog.location', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='Ydb.Monitoring.IssueLog.reason', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='Ydb.Monitoring.IssueLog.type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='Ydb.Monitoring.IssueLog.level', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listed', full_name='Ydb.Monitoring.IssueLog.listed', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='Ydb.Monitoring.IssueLog.count', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3076,
  serialized_end=3286,
)


_DATABASESTATUS = _descriptor.Descriptor(
  name='DatabaseStatus',
  full_name='Ydb.Monitoring.DatabaseStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Ydb.Monitoring.DatabaseStatus.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overall', full_name='Ydb.Monitoring.DatabaseStatus.overall', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage', full_name='Ydb.Monitoring.DatabaseStatus.storage', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compute', full_name='Ydb.Monitoring.DatabaseStatus.compute', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3289,
  serialized_end=3467,
)


_SELFCHECKRESULT = _descriptor.Descriptor(
  name='SelfCheckResult',
  full_name='Ydb.Monitoring.SelfCheckResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='self_check_result', full_name='Ydb.Monitoring.SelfCheckResult.self_check_result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issue_log', full_name='Ydb.Monitoring.SelfCheckResult.issue_log', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_status', full_name='Ydb.Monitoring.SelfCheckResult.database_status', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3470,
  serialized_end=3650,
)

_STATUSFLAG_STATUS.containing_type = _STATUSFLAG
_SELFCHECKREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_SELFCHECKREQUEST.fields_by_name['minimum_status'].enum_type = _STATUSFLAG_STATUS
_SELFCHECKRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_NODECHECKREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_NODECHECKRESPONSE.fields_by_name['operation'].message_type = protos_dot_ydb__operation__pb2._OPERATION
_SELFCHECK_RESULT.containing_type = _SELFCHECK
_STORAGEPDISKSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_STORAGEVDISKSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_STORAGEVDISKSTATUS.fields_by_name['vdisk_status'].enum_type = _STATUSFLAG_STATUS
_STORAGEVDISKSTATUS.fields_by_name['pdisk'].message_type = _STORAGEPDISKSTATUS
_STORAGEGROUPSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_STORAGEGROUPSTATUS.fields_by_name['vdisks'].message_type = _STORAGEVDISKSTATUS
_STORAGEPOOLSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_STORAGEPOOLSTATUS.fields_by_name['groups'].message_type = _STORAGEGROUPSTATUS
_STORAGESTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_STORAGESTATUS.fields_by_name['pools'].message_type = _STORAGEPOOLSTATUS
_COMPUTETABLETSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_THREADPOOLSTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_LOADAVERAGESTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_COMPUTENODESTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_COMPUTENODESTATUS.fields_by_name['tablets'].message_type = _COMPUTETABLETSTATUS
_COMPUTENODESTATUS.fields_by_name['pools'].message_type = _THREADPOOLSTATUS
_COMPUTENODESTATUS.fields_by_name['load'].message_type = _LOADAVERAGESTATUS
_COMPUTESTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_COMPUTESTATUS.fields_by_name['nodes'].message_type = _COMPUTENODESTATUS
_COMPUTESTATUS.fields_by_name['tablets'].message_type = _COMPUTETABLETSTATUS
_LOCATIONSTORAGEVDISK.fields_by_name['pdisk'].message_type = _LOCATIONSTORAGEPDISK
_LOCATIONSTORAGEGROUP.fields_by_name['vdisk'].message_type = _LOCATIONSTORAGEVDISK
_LOCATIONSTORAGEPOOL.fields_by_name['group'].message_type = _LOCATIONSTORAGEGROUP
_LOCATIONSTORAGE.fields_by_name['node'].message_type = _LOCATIONNODE
_LOCATIONSTORAGE.fields_by_name['pool'].message_type = _LOCATIONSTORAGEPOOL
_LOCATIONCOMPUTE.fields_by_name['node'].message_type = _LOCATIONNODE
_LOCATIONCOMPUTE.fields_by_name['pool'].message_type = _LOCATIONCOMPUTEPOOL
_LOCATIONCOMPUTE.fields_by_name['tablet'].message_type = _LOCATIONCOMPUTETABLET
_LOCATION.fields_by_name['storage'].message_type = _LOCATIONSTORAGE
_LOCATION.fields_by_name['compute'].message_type = _LOCATIONCOMPUTE
_LOCATION.fields_by_name['database'].message_type = _LOCATIONDATABASE
_ISSUELOG.fields_by_name['status'].enum_type = _STATUSFLAG_STATUS
_ISSUELOG.fields_by_name['location'].message_type = _LOCATION
_DATABASESTATUS.fields_by_name['overall'].enum_type = _STATUSFLAG_STATUS
_DATABASESTATUS.fields_by_name['storage'].message_type = _STORAGESTATUS
_DATABASESTATUS.fields_by_name['compute'].message_type = _COMPUTESTATUS
_SELFCHECKRESULT.fields_by_name['self_check_result'].enum_type = _SELFCHECK_RESULT
_SELFCHECKRESULT.fields_by_name['issue_log'].message_type = _ISSUELOG
_SELFCHECKRESULT.fields_by_name['database_status'].message_type = _DATABASESTATUS
DESCRIPTOR.message_types_by_name['StatusFlag'] = _STATUSFLAG
DESCRIPTOR.message_types_by_name['SelfCheckRequest'] = _SELFCHECKREQUEST
DESCRIPTOR.message_types_by_name['SelfCheckResponse'] = _SELFCHECKRESPONSE
DESCRIPTOR.message_types_by_name['NodeCheckRequest'] = _NODECHECKREQUEST
DESCRIPTOR.message_types_by_name['NodeCheckResponse'] = _NODECHECKRESPONSE
DESCRIPTOR.message_types_by_name['SelfCheck'] = _SELFCHECK
DESCRIPTOR.message_types_by_name['StoragePDiskStatus'] = _STORAGEPDISKSTATUS
DESCRIPTOR.message_types_by_name['StorageVDiskStatus'] = _STORAGEVDISKSTATUS
DESCRIPTOR.message_types_by_name['StorageGroupStatus'] = _STORAGEGROUPSTATUS
DESCRIPTOR.message_types_by_name['StoragePoolStatus'] = _STORAGEPOOLSTATUS
DESCRIPTOR.message_types_by_name['StorageStatus'] = _STORAGESTATUS
DESCRIPTOR.message_types_by_name['ComputeTabletStatus'] = _COMPUTETABLETSTATUS
DESCRIPTOR.message_types_by_name['ThreadPoolStatus'] = _THREADPOOLSTATUS
DESCRIPTOR.message_types_by_name['LoadAverageStatus'] = _LOADAVERAGESTATUS
DESCRIPTOR.message_types_by_name['ComputeNodeStatus'] = _COMPUTENODESTATUS
DESCRIPTOR.message_types_by_name['ComputeStatus'] = _COMPUTESTATUS
DESCRIPTOR.message_types_by_name['LocationNode'] = _LOCATIONNODE
DESCRIPTOR.message_types_by_name['LocationStoragePDisk'] = _LOCATIONSTORAGEPDISK
DESCRIPTOR.message_types_by_name['LocationStorageVDisk'] = _LOCATIONSTORAGEVDISK
DESCRIPTOR.message_types_by_name['LocationStorageGroup'] = _LOCATIONSTORAGEGROUP
DESCRIPTOR.message_types_by_name['LocationStoragePool'] = _LOCATIONSTORAGEPOOL
DESCRIPTOR.message_types_by_name['LocationStorage'] = _LOCATIONSTORAGE
DESCRIPTOR.message_types_by_name['LocationComputePool'] = _LOCATIONCOMPUTEPOOL
DESCRIPTOR.message_types_by_name['LocationComputeTablet'] = _LOCATIONCOMPUTETABLET
DESCRIPTOR.message_types_by_name['LocationCompute'] = _LOCATIONCOMPUTE
DESCRIPTOR.message_types_by_name['LocationDatabase'] = _LOCATIONDATABASE
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
DESCRIPTOR.message_types_by_name['IssueLog'] = _ISSUELOG
DESCRIPTOR.message_types_by_name['DatabaseStatus'] = _DATABASESTATUS
DESCRIPTOR.message_types_by_name['SelfCheckResult'] = _SELFCHECKRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatusFlag = _reflection.GeneratedProtocolMessageType('StatusFlag', (_message.Message,), {
  'DESCRIPTOR' : _STATUSFLAG,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StatusFlag)
  })
_sym_db.RegisterMessage(StatusFlag)

SelfCheckRequest = _reflection.GeneratedProtocolMessageType('SelfCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _SELFCHECKREQUEST,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.SelfCheckRequest)
  })
_sym_db.RegisterMessage(SelfCheckRequest)

SelfCheckResponse = _reflection.GeneratedProtocolMessageType('SelfCheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _SELFCHECKRESPONSE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.SelfCheckResponse)
  })
_sym_db.RegisterMessage(SelfCheckResponse)

NodeCheckRequest = _reflection.GeneratedProtocolMessageType('NodeCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _NODECHECKREQUEST,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.NodeCheckRequest)
  })
_sym_db.RegisterMessage(NodeCheckRequest)

NodeCheckResponse = _reflection.GeneratedProtocolMessageType('NodeCheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _NODECHECKRESPONSE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.NodeCheckResponse)
  })
_sym_db.RegisterMessage(NodeCheckResponse)

SelfCheck = _reflection.GeneratedProtocolMessageType('SelfCheck', (_message.Message,), {
  'DESCRIPTOR' : _SELFCHECK,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.SelfCheck)
  })
_sym_db.RegisterMessage(SelfCheck)

StoragePDiskStatus = _reflection.GeneratedProtocolMessageType('StoragePDiskStatus', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEPDISKSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StoragePDiskStatus)
  })
_sym_db.RegisterMessage(StoragePDiskStatus)

StorageVDiskStatus = _reflection.GeneratedProtocolMessageType('StorageVDiskStatus', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEVDISKSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StorageVDiskStatus)
  })
_sym_db.RegisterMessage(StorageVDiskStatus)

StorageGroupStatus = _reflection.GeneratedProtocolMessageType('StorageGroupStatus', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEGROUPSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StorageGroupStatus)
  })
_sym_db.RegisterMessage(StorageGroupStatus)

StoragePoolStatus = _reflection.GeneratedProtocolMessageType('StoragePoolStatus', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEPOOLSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StoragePoolStatus)
  })
_sym_db.RegisterMessage(StoragePoolStatus)

StorageStatus = _reflection.GeneratedProtocolMessageType('StorageStatus', (_message.Message,), {
  'DESCRIPTOR' : _STORAGESTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.StorageStatus)
  })
_sym_db.RegisterMessage(StorageStatus)

ComputeTabletStatus = _reflection.GeneratedProtocolMessageType('ComputeTabletStatus', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTETABLETSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.ComputeTabletStatus)
  })
_sym_db.RegisterMessage(ComputeTabletStatus)

ThreadPoolStatus = _reflection.GeneratedProtocolMessageType('ThreadPoolStatus', (_message.Message,), {
  'DESCRIPTOR' : _THREADPOOLSTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.ThreadPoolStatus)
  })
_sym_db.RegisterMessage(ThreadPoolStatus)

LoadAverageStatus = _reflection.GeneratedProtocolMessageType('LoadAverageStatus', (_message.Message,), {
  'DESCRIPTOR' : _LOADAVERAGESTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LoadAverageStatus)
  })
_sym_db.RegisterMessage(LoadAverageStatus)

ComputeNodeStatus = _reflection.GeneratedProtocolMessageType('ComputeNodeStatus', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTENODESTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.ComputeNodeStatus)
  })
_sym_db.RegisterMessage(ComputeNodeStatus)

ComputeStatus = _reflection.GeneratedProtocolMessageType('ComputeStatus', (_message.Message,), {
  'DESCRIPTOR' : _COMPUTESTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.ComputeStatus)
  })
_sym_db.RegisterMessage(ComputeStatus)

LocationNode = _reflection.GeneratedProtocolMessageType('LocationNode', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONNODE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationNode)
  })
_sym_db.RegisterMessage(LocationNode)

LocationStoragePDisk = _reflection.GeneratedProtocolMessageType('LocationStoragePDisk', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONSTORAGEPDISK,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationStoragePDisk)
  })
_sym_db.RegisterMessage(LocationStoragePDisk)

LocationStorageVDisk = _reflection.GeneratedProtocolMessageType('LocationStorageVDisk', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONSTORAGEVDISK,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationStorageVDisk)
  })
_sym_db.RegisterMessage(LocationStorageVDisk)

LocationStorageGroup = _reflection.GeneratedProtocolMessageType('LocationStorageGroup', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONSTORAGEGROUP,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationStorageGroup)
  })
_sym_db.RegisterMessage(LocationStorageGroup)

LocationStoragePool = _reflection.GeneratedProtocolMessageType('LocationStoragePool', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONSTORAGEPOOL,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationStoragePool)
  })
_sym_db.RegisterMessage(LocationStoragePool)

LocationStorage = _reflection.GeneratedProtocolMessageType('LocationStorage', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONSTORAGE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationStorage)
  })
_sym_db.RegisterMessage(LocationStorage)

LocationComputePool = _reflection.GeneratedProtocolMessageType('LocationComputePool', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONCOMPUTEPOOL,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationComputePool)
  })
_sym_db.RegisterMessage(LocationComputePool)

LocationComputeTablet = _reflection.GeneratedProtocolMessageType('LocationComputeTablet', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONCOMPUTETABLET,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationComputeTablet)
  })
_sym_db.RegisterMessage(LocationComputeTablet)

LocationCompute = _reflection.GeneratedProtocolMessageType('LocationCompute', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONCOMPUTE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationCompute)
  })
_sym_db.RegisterMessage(LocationCompute)

LocationDatabase = _reflection.GeneratedProtocolMessageType('LocationDatabase', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONDATABASE,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.LocationDatabase)
  })
_sym_db.RegisterMessage(LocationDatabase)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.Location)
  })
_sym_db.RegisterMessage(Location)

IssueLog = _reflection.GeneratedProtocolMessageType('IssueLog', (_message.Message,), {
  'DESCRIPTOR' : _ISSUELOG,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.IssueLog)
  })
_sym_db.RegisterMessage(IssueLog)

DatabaseStatus = _reflection.GeneratedProtocolMessageType('DatabaseStatus', (_message.Message,), {
  'DESCRIPTOR' : _DATABASESTATUS,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.DatabaseStatus)
  })
_sym_db.RegisterMessage(DatabaseStatus)

SelfCheckResult = _reflection.GeneratedProtocolMessageType('SelfCheckResult', (_message.Message,), {
  'DESCRIPTOR' : _SELFCHECKRESULT,
  '__module__' : 'protos.ydb_monitoring_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Monitoring.SelfCheckResult)
  })
_sym_db.RegisterMessage(SelfCheckResult)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
import jwt
import time

from ydb.oauth2_token_exchange import JwtTokenSource

PRIVATE_KEY = "-----BEGIN PRIVATE KEY-----\nMIIEvgIBADANBgkqhkiG9w0BAQEFAASCBKgwggSkAgEAAoIBAQC75/JS3rMcLJxv\nFgpOzF5+2gH+Yig3RE2MTl9uwC0BZKAv6foYr7xywQyWIK+W1cBhz8R4LfFmZo2j\nM0aCvdRmNBdW0EDSTnHLxCsFhoQWLVq+bI5f5jzkcoiioUtaEpADPqwgVULVtN/n\nnPJiZ6/dU30C3jmR6+LUgEntUtWt3eq3xQIn5lG3zC1klBY/HxtfH5Hu8xBvwRQT\nJnh3UpPLj8XwSmriDgdrhR7o6umWyVuGrMKlLHmeivlfzjYtfzO1MOIMG8t2/zxG\nR+xb4Vwks73sH1KruH/0/JMXU97npwpe+Um+uXhpldPygGErEia7abyZB2gMpXqr\nWYKMo02NAgMBAAECggEAO0BpC5OYw/4XN/optu4/r91bupTGHKNHlsIR2rDzoBhU\nYLd1evpTQJY6O07EP5pYZx9mUwUdtU4KRJeDGO/1/WJYp7HUdtxwirHpZP0lQn77\nuccuX/QQaHLrPekBgz4ONk+5ZBqukAfQgM7fKYOLk41jgpeDbM2Ggb6QUSsJISEp\nzrwpI/nNT/wn+Hvx4DxrzWU6wF+P8kl77UwPYlTA7GsT+T7eKGVH8xsxmK8pt6lg\nsvlBA5XosWBWUCGLgcBkAY5e4ZWbkdd183o+oMo78id6C+PQPE66PLDtHWfpRRmN\nm6XC03x6NVhnfvfozoWnmS4+e4qj4F/emCHvn0GMywKBgQDLXlj7YPFVXxZpUvg/\nrheVcCTGbNmQJ+4cZXx87huqwqKgkmtOyeWsRc7zYInYgraDrtCuDBCfP//ZzOh0\nLxepYLTPk5eNn/GT+VVrqsy35Ccr60g7Lp/bzb1WxyhcLbo0KX7/6jl0lP+VKtdv\nmto+4mbSBXSM1Y5BVVoVgJ3T/wKBgQDsiSvPRzVi5TTj13x67PFymTMx3HCe2WzH\nJUyepCmVhTm482zW95pv6raDr5CTO6OYpHtc5sTTRhVYEZoEYFTM9Vw8faBtluWG\nBjkRh4cIpoIARMn74YZKj0C/0vdX7SHdyBOU3bgRPHg08Hwu3xReqT1kEPSI/B2V\n4pe5fVrucwKBgQCNFgUxUA3dJjyMES18MDDYUZaRug4tfiYouRdmLGIxUxozv6CG\nZnbZzwxFt+GpvPUV4f+P33rgoCvFU+yoPctyjE6j+0aW0DFucPmb2kBwCu5J/856\nkFwCx3blbwFHAco+SdN7g2kcwgmV2MTg/lMOcU7XwUUcN0Obe7UlWbckzQKBgQDQ\nnXaXHL24GGFaZe4y2JFmujmNy1dEsoye44W9ERpf9h1fwsoGmmCKPp90az5+rIXw\nFXl8CUgk8lXW08db/r4r+ma8Lyx0GzcZyplAnaB5/6j+pazjSxfO4KOBy4Y89Tb+\nTP0AOcCi6ws13bgY+sUTa/5qKA4UVw+c5zlb7nRpgwKBgGXAXhenFw1666482iiN\ncHSgwc4ZHa1oL6aNJR1XWH+aboBSwR+feKHUPeT4jHgzRGo/aCNHD2FE5I8eBv33\nof1kWYjAO0YdzeKrW0rTwfvt9gGg+CS397aWu4cy+mTI+MNfBgeDAIVBeJOJXLlX\nhL8bFAuNNVrCOp79TNnNIsh7\n-----END PRIVATE KEY-----\n"  # noqa: E501
PUBLIC_KEY = "-----BEGIN PUBLIC KEY-----\nMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAu+fyUt6zHCycbxYKTsxe\nftoB/mIoN0RNjE5fbsAtAWSgL+n6GK+8csEMliCvltXAYc/EeC3xZmaNozNGgr3U\nZjQXVtBA0k5xy8QrBYaEFi1avmyOX+Y85HKIoqFLWhKQAz6sIFVC1bTf55zyYmev\n3VN9At45kevi1IBJ7VLVrd3qt8UCJ+ZRt8wtZJQWPx8bXx+R7vMQb8EUEyZ4d1KT\ny4/F8Epq4g4Ha4Ue6OrplslbhqzCpSx5nor5X842LX8ztTDiDBvLdv88RkfsW+Fc\nJLO97B9Sq7h/9PyTF1Pe56cKXvlJvrl4aZXT8oBhKxImu2m8mQdoDKV6q1mCjKNN\njQIDAQAB\n-----END PUBLIC KEY-----\n"  # noqa: E501


def check_exception(f):
    try:
        f()
    except Exception:
        return
    assert False, "Exception is expected"


def test_no_signing_method():
    def f():
        JwtTokenSource(signing_method="", private_key=PRIVATE_KEY, key_id="key_id")

    check_exception(f)


def test_no_private_key():
    def f():
        JwtTokenSource(signing_method="RS256", private_key="", key_id="key_id")

    check_exception(f)


def test_incorrect_ttl():
    def f():
        JwtTokenSource(signing_method="RS256", private_key=PRIVATE_KEY, key_id="key_id", token_ttl_seconds=0)

    check_exception(f)


def test_jwt_encode():
    aud = ["aud1", "aud2"]
    src = JwtTokenSource(
        signing_method="RS256",
        private_key=PRIVATE_KEY,
        key_id="key_id",
        subject="subject",
        audience=aud,
    )
    jwt_token = src.token()
    assert jwt_token.token_type == "urn:ietf:params:oauth:token-type:jwt"

    decoded = jwt.decode(jwt_token.token, key=PUBLIC_KEY, algorithms=["RS256"], audience=aud)
    assert decoded.get("iss") is None
    assert decoded["sub"] == "subject"
    assert decoded["aud"] == aud
    assert abs(decoded["iat"] - time.time()) <= 60
    assert abs(decoded["exp"] - time.time()) <= 3600



from protos import ydb_operation_pb2 as _ydb_operation_pb2
from protos import ydb_value_pb2 as _ydb_value_pb2
from protos import ydb_table_pb2 as _ydb_table_pb2
from protos import ydb_query_stats_pb2 as _ydb_query_stats_pb2
from protos import ydb_issue_message_pb2 as _ydb_issue_message_pb2
from protos import ydb_status_codes_pb2 as _ydb_status_codes_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExecuteYqlPartialResponse(_message.Message):
    __slots__ = ["issues", "result", "status"]
    ISSUES_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
    result: ExecuteYqlPartialResult
    status: _ydb_status_codes_pb2.StatusIds.StatusCode
    def __init__(self, status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ..., result: _Optional[_Union[ExecuteYqlPartialResult, _Mapping]] = ...) -> None: ...

class ExecuteYqlPartialResult(_message.Message):
    __slots__ = ["query_stats", "result_set", "result_set_index"]
    QUERY_STATS_FIELD_NUMBER: _ClassVar[int]
    RESULT_SET_FIELD_NUMBER: _ClassVar[int]
    RESULT_SET_INDEX_FIELD_NUMBER: _ClassVar[int]
    query_stats: _ydb_query_stats_pb2.QueryStats
    result_set: _ydb_value_pb2.ResultSet
    result_set_index: int
    def __init__(self, result_set_index: _Optional[int] = ..., result_set: _Optional[_Union[_ydb_value_pb2.ResultSet, _Mapping]] = ..., query_stats: _Optional[_Union[_ydb_query_stats_pb2.QueryStats, _Mapping]] = ...) -> None: ...

class ExecuteYqlRequest(_message.Message):
    __slots__ = ["collect_stats", "operation_params", "parameters", "script"]
    class ParametersEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _ydb_value_pb2.TypedValue
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_ydb_value_pb2.TypedValue, _Mapping]] = ...) -> None: ...
    COLLECT_STATS_FIELD_NUMBER: _ClassVar[int]
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    SCRIPT_FIELD_NUMBER: _ClassVar[int]
    collect_stats: _ydb_table_pb2.QueryStatsCollection.Mode
    operation_params: _ydb_operation_pb2.OperationParams
    parameters: _containers.MessageMap[str, _ydb_value_pb2.TypedValue]
    script: str
    def __init__(self, operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ..., script: _Optional[str] = ..., parameters: _Optional[_Mapping[str, _ydb_value_pb2.TypedValue]] = ..., collect_stats: _Optional[_Union[_ydb_table_pb2.QueryStatsCollection.Mode, str]] = ...) -> None: ...

class ExecuteYqlResponse(_message.Message):
    __slots__ = ["operation"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class ExecuteYqlResult(_message.Message):
    __slots__ = ["query_stats", "result_sets"]
    QUERY_STATS_FIELD_NUMBER: _ClassVar[int]
    RESULT_SETS_FIELD_NUMBER: _ClassVar[int]
    query_stats: _ydb_query_stats_pb2.QueryStats
    result_sets: _containers.RepeatedCompositeFieldContainer[_ydb_value_pb2.ResultSet]
    def __init__(self, result_sets: _Optional[_Iterable[_Union[_ydb_value_pb2.ResultSet, _Mapping]]] = ..., query_stats: _Optional[_Union[_ydb_query_stats_pb2.QueryStats, _Mapping]] = ...) -> None: ...

class ExplainYqlRequest(_message.Message):
    __slots__ = ["mode", "operation_params", "script"]
    class Mode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    MODE_FIELD_NUMBER: _ClassVar[int]
    MODE_UNSPECIFIED: ExplainYqlRequest.Mode
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PLAN: ExplainYqlRequest.Mode
    SCRIPT_FIELD_NUMBER: _ClassVar[int]
    VALIDATE: ExplainYqlRequest.Mode
    mode: ExplainYqlRequest.Mode
    operation_params: _ydb_operation_pb2.OperationParams
    script: str
    def __init__(self, operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ..., script: _Optional[str] = ..., mode: _Optional[_Union[ExplainYqlRequest.Mode, str]] = ...) -> None: ...

class ExplainYqlResponse(_message.Message):
    __slots__ = ["operation"]
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class ExplainYqlResult(_message.Message):
    __slots__ = ["parameters_types", "plan"]
    class ParametersTypesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _ydb_value_pb2.Type
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_ydb_value_pb2.Type, _Mapping]] = ...) -> None: ...
    PARAMETERS_TYPES_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    parameters_types: _containers.MessageMap[str, _ydb_value_pb2.Type]
    plan: str
    def __init__(self, parameters_types: _Optional[_Mapping[str, _ydb_value_pb2.Type]] = ..., plan: _Optional[str] = ...) -> None: ...



from typing import List

import pytest

from .topic_writer import _split_messages_by_size


@pytest.mark.parametrize(
    "messages,split_size,expected",
    [
        (
            [1, 2, 3],
            0,
            [[1], [2], [3]],
        ),
        (
            [1, 2, 3],
            1,
            [[1], [2], [3]],
        ),
        (
            [1, 2, 3],
            3,
            [[1, 2], [3]],
        ),
        (
            [1, 2, 3],
            100,
            [[1, 2, 3]],
        ),
        (
            [100, 2, 3],
            100,
            [[100], [2, 3]],
        ),
        (
            [],
            100,
            [],
        ),
        (
            [],
            100,
            [],
        ),
    ],
)
def test_split_messages_by_size(messages: List[int], split_size: int, expected: List[List[int]]):
    res = _split_messages_by_size(messages, split_size, lambda x: x)  # noqa
    assert res == expected



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/ydb_value.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'protos/ydb_value.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from ydb._grpc.v6.protos import ydb_formats_pb2 as protos_dot_ydb__formats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16protos/ydb_value.proto\x12\x03Ydb\x1a\x1cgoogle/protobuf/struct.proto\x1a\x18protos/ydb_formats.proto\"/\n\x0b\x44\x65\x63imalType\x12\x11\n\tprecision\x18\x01 \x01(\r\x12\r\n\x05scale\x18\x02 \x01(\r\"\'\n\x0cOptionalType\x12\x17\n\x04item\x18\x01 \x01(\x0b\x32\t.Ydb.Type\"#\n\x08ListType\x12\x17\n\x04item\x18\x01 \x01(\x0b\x32\t.Ydb.Type\"e\n\x0bVariantType\x12%\n\x0btuple_items\x18\x01 \x01(\x0b\x32\x0e.Ydb.TupleTypeH\x00\x12\'\n\x0cstruct_items\x18\x02 \x01(\x0b\x32\x0f.Ydb.StructTypeH\x00\x42\x06\n\x04type\"(\n\tTupleType\x12\x1b\n\x08\x65lements\x18\x01 \x03(\x0b\x32\t.Ydb.Type\"5\n\x0cStructMember\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x04type\x18\x02 \x01(\x0b\x32\t.Ydb.Type\"0\n\nStructType\x12\"\n\x07members\x18\x01 \x03(\x0b\x32\x11.Ydb.StructMember\">\n\x08\x44ictType\x12\x16\n\x03key\x18\x01 \x01(\x0b\x32\t.Ydb.Type\x12\x1a\n\x07payload\x18\x02 \x01(\x0b\x32\t.Ydb.Type\"2\n\nTaggedType\x12\x0b\n\x03tag\x18\x01 \x01(\t\x12\x17\n\x04type\x18\x02 \x01(\x0b\x32\t.Ydb.Type\"_\n\x06PgType\x12\x11\n\ttype_name\x18\n \x01(\t\x12\x15\n\rtype_modifier\x18\x0b \x01(\t\x12\x0b\n\x03oid\x18\x01 \x01(\r\x12\x0e\n\x06typlen\x18\x02 \x01(\x05\x12\x0e\n\x06typmod\x18\x03 \x01(\x05\"\x9f\x08\n\x04Type\x12,\n\x07type_id\x18\x01 \x01(\x0e\x32\x19.Ydb.Type.PrimitiveTypeIdH\x00\x12(\n\x0c\x64\x65\x63imal_type\x18\x02 \x01(\x0b\x32\x10.Ydb.DecimalTypeH\x00\x12*\n\roptional_type\x18\x65 \x01(\x0b\x32\x11.Ydb.OptionalTypeH\x00\x12\"\n\tlist_type\x18\x66 \x01(\x0b\x32\r.Ydb.ListTypeH\x00\x12$\n\ntuple_type\x18g \x01(\x0b\x32\x0e.Ydb.TupleTypeH\x00\x12&\n\x0bstruct_type\x18h \x01(\x0b\x32\x0f.Ydb.StructTypeH\x00\x12\"\n\tdict_type\x18i \x01(\x0b\x32\r.Ydb.DictTypeH\x00\x12(\n\x0cvariant_type\x18j \x01(\x0b\x32\x10.Ydb.VariantTypeH\x00\x12&\n\x0btagged_type\x18k \x01(\x0b\x32\x0f.Ydb.TaggedTypeH\x00\x12\x30\n\tvoid_type\x18\xc9\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x30\n\tnull_type\x18\xca\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x36\n\x0f\x65mpty_list_type\x18\xcb\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x36\n\x0f\x65mpty_dict_type\x18\xcc\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x1f\n\x07pg_type\x18\xcd\x01 \x01(\x0b\x32\x0b.Ydb.PgTypeH\x00\"\xad\x03\n\x0fPrimitiveTypeId\x12!\n\x1dPRIMITIVE_TYPE_ID_UNSPECIFIED\x10\x00\x12\x08\n\x04\x42OOL\x10\x06\x12\x08\n\x04INT8\x10\x07\x12\t\n\x05UINT8\x10\x05\x12\t\n\x05INT16\x10\x08\x12\n\n\x06UINT16\x10\t\x12\t\n\x05INT32\x10\x01\x12\n\n\x06UINT32\x10\x02\x12\t\n\x05INT64\x10\x03\x12\n\n\x06UINT64\x10\x04\x12\t\n\x05\x46LOAT\x10!\x12\n\n\x06\x44OUBLE\x10 \x12\x08\n\x04\x44\x41TE\x10\x30\x12\x0c\n\x08\x44\x41TETIME\x10\x31\x12\r\n\tTIMESTAMP\x10\x32\x12\x0c\n\x08INTERVAL\x10\x33\x12\x0b\n\x07TZ_DATE\x10\x34\x12\x0f\n\x0bTZ_DATETIME\x10\x35\x12\x10\n\x0cTZ_TIMESTAMP\x10\x36\x12\n\n\x06\x44\x41TE32\x10@\x12\x0e\n\nDATETIME64\x10\x41\x12\x0f\n\x0bTIMESTAMP64\x10\x42\x12\x0e\n\nINTERVAL64\x10\x43\x12\x0b\n\x06STRING\x10\x81 \x12\t\n\x04UTF8\x10\x80$\x12\t\n\x04YSON\x10\x81$\x12\t\n\x04JSON\x10\x82$\x12\t\n\x04UUID\x10\x83$\x12\x12\n\rJSON_DOCUMENT\x10\x84$\x12\r\n\x08\x44YNUMBER\x10\x82&B\x06\n\x04type\"A\n\tValuePair\x12\x17\n\x03key\x18\x01 \x01(\x0b\x32\n.Ydb.Value\x12\x1b\n\x07payload\x18\x02 \x01(\x0b\x32\n.Ydb.Value\"\xb1\x03\n\x05Value\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x15\n\x0bint32_value\x18\x02 \x01(\x0fH\x00\x12\x16\n\x0cuint32_value\x18\x03 \x01(\x07H\x00\x12\x15\n\x0bint64_value\x18\x04 \x01(\x10H\x00\x12\x16\n\x0cuint64_value\x18\x05 \x01(\x06H\x00\x12\x15\n\x0b\x66loat_value\x18\x06 \x01(\x02H\x00\x12\x16\n\x0c\x64ouble_value\x18\x07 \x01(\x01H\x00\x12\x15\n\x0b\x62ytes_value\x18\x08 \x01(\x0cH\x00\x12\x14\n\ntext_value\x18\t \x01(\tH\x00\x12\x35\n\x0fnull_flag_value\x18\n \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\"\n\x0cnested_value\x18\x0b \x01(\x0b\x32\n.Ydb.ValueH\x00\x12\x11\n\x07low_128\x18\x0f \x01(\x06H\x00\x12\x19\n\x05items\x18\x0c \x03(\x0b\x32\n.Ydb.Value\x12\x1d\n\x05pairs\x18\r \x03(\x0b\x32\x0e.Ydb.ValuePair\x12\x15\n\rvariant_index\x18\x0e \x01(\r\x12\x10\n\x08high_128\x18\x10 \x01(\x06\x42\x07\n\x05value\"@\n\nTypedValue\x12\x17\n\x04type\x18\x01 \x01(\x0b\x32\t.Ydb.Type\x12\x19\n\x05value\x18\x02 \x01(\x0b\x32\n.Ydb.Value\"/\n\x06\x43olumn\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x04type\x18\x02 \x01(\x0b\x32\t.Ydb.Type\"\x8a\x02\n\tResultSet\x12\x1c\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x0b.Ydb.Column\x12\x18\n\x04rows\x18\x02 \x03(\x0b\x32\n.Ydb.Value\x12\x11\n\ttruncated\x18\x03 \x01(\x08\x12%\n\x06\x66ormat\x18\x04 \x01(\x0e\x32\x15.Ydb.ResultSet.Format\x12\x37\n\x11\x61rrow_format_meta\x18\x05 \x01(\x0b\x32\x1c.Ydb.Formats.ArrowFormatMeta\x12\x0c\n\x04\x64\x61ta\x18\x0f \x01(\x0c\"D\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x46ORMAT_VALUE\x10\x01\x12\x10\n\x0c\x46ORMAT_ARROW\x10\x02\x42T\n\x0etech.ydb.protoB\x0bValueProtosZ2github.com/ydb-platform/ydb-go-genproto/protos/Ydb\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_value_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016tech.ydb.protoB\013ValueProtosZ2github.com/ydb-platform/ydb-go-genproto/protos/Ydb\370\001\001'
  _globals['_DECIMALTYPE']._serialized_start=87
  _globals['_DECIMALTYPE']._serialized_end=134
  _globals['_OPTIONALTYPE']._serialized_start=136
  _globals['_OPTIONALTYPE']._serialized_end=175
  _globals['_LISTTYPE']._serialized_start=177
  _globals['_LISTTYPE']._serialized_end=212
  _globals['_VARIANTTYPE']._serialized_start=214
  _globals['_VARIANTTYPE']._serialized_end=315
  _globals['_TUPLETYPE']._serialized_start=317
  _globals['_TUPLETYPE']._serialized_end=357
  _globals['_STRUCTMEMBER']._serialized_start=359
  _globals['_STRUCTMEMBER']._serialized_end=412
  _globals['_STRUCTTYPE']._serialized_start=414
  _globals['_STRUCTTYPE']._serialized_end=462
  _globals['_DICTTYPE']._serialized_start=464
  _globals['_DICTTYPE']._serialized_end=526
  _globals['_TAGGEDTYPE']._serialized_start=528
  _globals['_TAGGEDTYPE']._serialized_end=578
  _globals['_PGTYPE']._serialized_start=580
  _globals['_PGTYPE']._serialized_end=675
  _globals['_TYPE']._serialized_start=678
  _globals['_TYPE']._serialized_end=1733
  _globals['_TYPE_PRIMITIVETYPEID']._serialized_start=1296
  _globals['_TYPE_PRIMITIVETYPEID']._serialized_end=1725
  _globals['_VALUEPAIR']._serialized_start=1735
  _globals['_VALUEPAIR']._serialized_end=1800
  _globals['_VALUE']._serialized_start=1803
  _globals['_VALUE']._serialized_end=2236
  _globals['_TYPEDVALUE']._serialized_start=2238
  _globals['_TYPEDVALUE']._serialized_end=2302
  _globals['_COLUMN']._serialized_start=2304
  _globals['_COLUMN']._serialized_end=2351
  _globals['_RESULTSET']._serialized_start=2354
  _globals['_RESULTSET']._serialized_end=2620
  _globals['_RESULTSET_FORMAT']._serialized_start=2552
  _globals['_RESULTSET_FORMAT']._serialized_end=2620
# @@protoc_insertion_point(module_scope)



import warnings

from . import convert
from . import table


def global_allow_truncated_result(enabled: bool = True):
    if convert._default_allow_truncated_result == enabled:
        return

    if enabled:
        warnings.warn("Global allow truncated response is deprecated behaviour.")

    convert._default_allow_truncated_result = enabled


def global_allow_split_transactions(enabled: bool):
    if table._default_allow_split_transaction == enabled:
        return

    if enabled:
        warnings.warn("Global allow split transaction is deprecated behaviour.")

    table._default_allow_split_transaction = enabled



import asyncio
import time
import typing

from .._grpc.grpcwrapper.common_utils import IToProto, IGrpcWrapperAsyncIO


class StreamMock(IGrpcWrapperAsyncIO):
    from_server: asyncio.Queue
    from_client: asyncio.Queue
    _closed: bool

    def __init__(self):
        self.from_server = asyncio.Queue()
        self.from_client = asyncio.Queue()
        self._closed = False

    async def receive(self, timeout: typing.Optional[int] = None) -> typing.Any:
        if self._closed:
            raise Exception("read from closed StreamMock")

        item = await self.from_server.get()
        if item is None:
            raise StopAsyncIteration()
        if isinstance(item, Exception):
            raise item
        return item

    def write(self, wrap_message: IToProto):
        if self._closed:
            raise Exception("write to closed StreamMock")
        self.from_client.put_nowait(wrap_message)

    def close(self):
        if self._closed:
            return

        self._closed = True
        self.from_server.put_nowait(None)


class WaitConditionError(Exception):
    pass


async def wait_condition(
    f: typing.Callable[[], bool],
    timeout: typing.Optional[typing.Union[float, int]] = None,
):
    """
    timeout default is 1 second
    if timeout is 0 - only counter work. It userful if test need fast timeout for condition (without wait full timeout)
    """
    if timeout is None:
        timeout = 1

    minimal_loop_count_for_wait = 1000

    start = time.monotonic()
    counter = 0
    while (time.monotonic() - start < timeout) or counter < minimal_loop_count_for_wait:
        counter += 1
        if f():
            return
        await asyncio.sleep(0)

    raise WaitConditionError("Bad condition in test")


async def wait_for_fast(
    awaitable: typing.Union[typing.Awaitable, typing.Coroutine],
    timeout: typing.Optional[typing.Union[float, int]] = None,
):
    fut = asyncio.ensure_future(awaitable)
    await wait_condition(lambda: fut.done(), timeout)
    return fut.result()



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_import.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v5.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v5.protos import ydb_export_pb2 as protos_dot_ydb__export__pb2
from ydb._grpc.v5.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17protos/ydb_import.proto\x12\nYdb.Import\x1a#protos/annotations/validation.proto\x1a\x17protos/ydb_export.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xee\x01\n\x0eImportProgress\"\xdb\x01\n\x08Progress\x12\x18\n\x14PROGRESS_UNSPECIFIED\x10\x00\x12\x16\n\x12PROGRESS_PREPARING\x10\x01\x12\x1a\n\x16PROGRESS_TRANSFER_DATA\x10\x02\x12\x1a\n\x16PROGRESS_BUILD_INDEXES\x10\x03\x12\x11\n\rPROGRESS_DONE\x10\x04\x12\x19\n\x15PROGRESS_CANCELLATION\x10\x05\x12\x16\n\x12PROGRESS_CANCELLED\x10\x06\x12\x1f\n\x1bPROGRESS_CREATE_CHANGEFEEDS\x10\x07\"\xa0\x01\n\x12ImportItemProgress\x12\x13\n\x0bparts_total\x18\x01 \x01(\r\x12\x17\n\x0fparts_completed\x18\x02 \x01(\r\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xfb\x06\n\x14ImportFromS3Settings\x12\x16\n\x08\x65ndpoint\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x37\n\x06scheme\x18\x02 \x01(\x0e\x32\'.Ydb.Import.ImportFromS3Settings.Scheme\x12\x14\n\x06\x62ucket\x18\x03 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\naccess_key\x18\x04 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\nsecret_key\x18\x05 \x01(\tB\x04\x90\xe6*\x01\x12\x34\n\x05items\x18\x06 \x03(\x0b\x32%.Ydb.Import.ImportFromS3Settings.Item\x12\x1c\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x11number_of_retries\x18\x08 \x01(\r\x12\x0e\n\x06region\x18\t \x01(\t\x12\"\n\x1a\x64isable_virtual_addressing\x18\n \x01(\x08\x12\x0e\n\x06no_acl\x18\x0b \x01(\x08\x12 \n\x18skip_checksum_validation\x18\x0c \x01(\x08\x12\x15\n\rsource_prefix\x18\r \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x0e \x01(\t\x12;\n\x13\x65ncryption_settings\x18\x0f \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12M\n\x12index_filling_mode\x18\x10 \x01(\x0e\x32\x31.Ydb.Import.ImportFromS3Settings.IndexFillingMode\x12\x17\n\x0f\x65xclude_regexps\x18\x11 \x03(\t\x1aZ\n\x04Item\x12\x17\n\rsource_prefix\x18\x01 \x01(\tH\x00\x12\x15\n\x0bsource_path\x18\x03 \x01(\tH\x00\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\tB\x08\n\x06Source\".\n\x06Scheme\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02\"\x90\x01\n\x10IndexFillingMode\x12\"\n\x1eINDEX_FILLING_MODE_UNSPECIFIED\x10\x00\x12\x1c\n\x18INDEX_FILLING_MODE_BUILD\x10\x01\x12\x1d\n\x19INDEX_FILLING_MODE_IMPORT\x10\x02\x12\x1b\n\x17INDEX_FILLING_MODE_AUTO\x10\x03\"\x14\n\x12ImportFromS3Result\"\xb9\x01\n\x14ImportFromS3Metadata\x12\x32\n\x08settings\x18\x01 \x01(\x0b\x32 .Ydb.Import.ImportFromS3Settings\x12\x35\n\x08progress\x18\x02 \x01(\x0e\x32#.Ydb.Import.ImportProgress.Progress\x12\x36\n\x0eitems_progress\x18\x03 \x03(\x0b\x32\x1e.Ydb.Import.ImportItemProgress\"\x8a\x01\n\x13ImportFromS3Request\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x38\n\x08settings\x18\x02 \x01(\x0b\x32 .Ydb.Import.ImportFromS3SettingsB\x04\x90\xe6*\x01\"D\n\x14ImportFromS3Response\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xf7\x02\n\x14ImportFromFsSettings\x12\x17\n\tbase_path\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x34\n\x05items\x18\x02 \x03(\x0b\x32%.Ydb.Import.ImportFromFsSettings.Item\x12\x1c\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x01\x12\x19\n\x11number_of_retries\x18\x04 \x01(\r\x12\x0e\n\x06no_acl\x18\x05 \x01(\x08\x12 \n\x18skip_checksum_validation\x18\x06 \x01(\x08\x12\x18\n\x10\x64\x65stination_path\x18\x07 \x01(\t\x12;\n\x13\x65ncryption_settings\x18\x08 \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12\x17\n\x0f\x65xclude_regexps\x18\t \x03(\t\x1a\x35\n\x04Item\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\"\x14\n\x12ImportFromFsResult\"\xb9\x01\n\x14ImportFromFsMetadata\x12\x32\n\x08settings\x18\x01 \x01(\x0b\x32 .Ydb.Import.ImportFromFsSettings\x12\x35\n\x08progress\x18\x02 \x01(\x0e\x32#.Ydb.Import.ImportProgress.Progress\x12\x36\n\x0eitems_progress\x18\x03 \x03(\x0b\x32\x1e.Ydb.Import.ImportItemProgress\"\x8a\x01\n\x13ImportFromFsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x38\n\x08settings\x18\x02 \x01(\x0b\x32 .Ydb.Import.ImportFromFsSettingsB\x04\x90\xe6*\x01\"D\n\x14ImportFromFsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xc4\x03\n\x1dListObjectsInS3ExportSettings\x12\x16\n\x08\x65ndpoint\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x37\n\x06scheme\x18\x02 \x01(\x0e\x32\'.Ydb.Import.ImportFromS3Settings.Scheme\x12\x14\n\x06\x62ucket\x18\x03 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\naccess_key\x18\x04 \x01(\tB\x04\x90\xe6*\x01\x12\x18\n\nsecret_key\x18\x05 \x01(\tB\x04\x90\xe6*\x01\x12=\n\x05items\x18\x06 \x03(\x0b\x32..Ydb.Import.ListObjectsInS3ExportSettings.Item\x12\x19\n\x11number_of_retries\x18\x07 \x01(\r\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\"\n\x1a\x64isable_virtual_addressing\x18\t \x01(\x08\x12\x0e\n\x06prefix\x18\n \x01(\t\x12;\n\x13\x65ncryption_settings\x18\x0b \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12\x17\n\x0f\x65xclude_regexps\x18\x0c \x03(\t\x1a\x14\n\x04Item\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x99\x01\n\x1bListObjectsInS3ExportResult\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.Ydb.Import.ListObjectsInS3ExportResult.Item\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a$\n\x04Item\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xd1\x01\n\x1cListObjectsInS3ExportRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x41\n\x08settings\x18\x02 \x01(\x0b\x32).Ydb.Import.ListObjectsInS3ExportSettingsB\x04\x90\xe6*\x01\x12\x1f\n\tpage_size\x18\x03 \x01(\x03\x42\x0c\xb2\xe6*\x08<= 10000\x12\x12\n\npage_token\x18\x04 \x01(\t\"M\n\x1dListObjectsInS3ExportResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xfe\x01\n\x1dListObjectsInFsExportSettings\x12\x17\n\tbase_path\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12=\n\x05items\x18\x02 \x03(\x0b\x32..Ydb.Import.ListObjectsInFsExportSettings.Item\x12\x19\n\x11number_of_retries\x18\x03 \x01(\r\x12;\n\x13\x65ncryption_settings\x18\x04 \x01(\x0b\x32\x1e.Ydb.Export.EncryptionSettings\x12\x17\n\x0f\x65xclude_regexps\x18\x05 \x03(\t\x1a\x14\n\x04Item\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x9d\x01\n\x1bListObjectsInFsExportResult\x12;\n\x05items\x18\x01 \x03(\x0b\x32,.Ydb.Import.ListObjectsInFsExportResult.Item\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a(\n\x04Item\x12\x0f\n\x07\x66s_path\x18\x01 \x01(\t\x12\x0f\n\x07\x64\x62_path\x18\x02 \x01(\t\"\xd1\x01\n\x1cListObjectsInFsExportRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x41\n\x08settings\x18\x02 \x01(\x0b\x32).Ydb.Import.ListObjectsInFsExportSettingsB\x04\x90\xe6*\x01\x12\x1f\n\tpage_size\x18\x03 \x01(\x03\x42\x0c\xb2\xe6*\x08<= 10000\x12\x12\n\npage_token\x18\x04 \x01(\t\"M\n\x1dListObjectsInFsExportResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\" \n\rYdbDumpFormat\x12\x0f\n\x07\x63olumns\x18\x01 \x03(\t\"\x12\n\x10ImportDataResult\"\xae\x01\n\x11ImportDataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x17\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\t\xa2\xe6*\x05\x18\x80\x80\x80\x08\x12-\n\x08ydb_dump\x18\x04 \x01(\x0b\x32\x19.Ydb.Import.YdbDumpFormatH\x00\x42\x08\n\x06\x66ormat\"B\n\x12ImportDataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationBV\n\x16tech.ydb.proto.import_Z9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Import\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_import_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026tech.ydb.proto.import_Z9github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Import\370\001\001'
  _IMPORTFROMS3SETTINGS.fields_by_name['endpoint']._options = None
  _IMPORTFROMS3SETTINGS.fields_by_name['endpoint']._serialized_options = b'\220\346*\001'
  _IMPORTFROMS3SETTINGS.fields_by_name['bucket']._options = None
  _IMPORTFROMS3SETTINGS.fields_by_name['bucket']._serialized_options = b'\220\346*\001'
  _IMPORTFROMS3SETTINGS.fields_by_name['access_key']._options = None
  _IMPORTFROMS3SETTINGS.fields_by_name['access_key']._serialized_options = b'\220\346*\001'
  _IMPORTFROMS3SETTINGS.fields_by_name['secret_key']._options = None
  _IMPORTFROMS3SETTINGS.fields_by_name['secret_key']._serialized_options = b'\220\346*\001'
  _IMPORTFROMS3SETTINGS.fields_by_name['description']._options = None
  _IMPORTFROMS3SETTINGS.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200\001'
  _IMPORTFROMS3REQUEST.fields_by_name['settings']._options = None
  _IMPORTFROMS3REQUEST.fields_by_name['settings']._serialized_options = b'\220\346*\001'
  _IMPORTFROMFSSETTINGS.fields_by_name['base_path']._options = None
  _IMPORTFROMFSSETTINGS.fields_by_name['base_path']._serialized_options = b'\220\346*\001'
  _IMPORTFROMFSSETTINGS.fields_by_name['description']._options = None
  _IMPORTFROMFSSETTINGS.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200\001'
  _IMPORTFROMFSREQUEST.fields_by_name['settings']._options = None
  _IMPORTFROMFSREQUEST.fields_by_name['settings']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['endpoint']._options = None
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['endpoint']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['bucket']._options = None
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['bucket']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['access_key']._options = None
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['access_key']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['secret_key']._options = None
  _LISTOBJECTSINS3EXPORTSETTINGS.fields_by_name['secret_key']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['settings']._options = None
  _LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['settings']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['page_size']._options = None
  _LISTOBJECTSINS3EXPORTREQUEST.fields_by_name['page_size']._serialized_options = b'\262\346*\010<= 10000'
  _LISTOBJECTSINFSEXPORTSETTINGS.fields_by_name['base_path']._options = None
  _LISTOBJECTSINFSEXPORTSETTINGS.fields_by_name['base_path']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['settings']._options = None
  _LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['settings']._serialized_options = b'\220\346*\001'
  _LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['page_size']._options = None
  _LISTOBJECTSINFSEXPORTREQUEST.fields_by_name['page_size']._serialized_options = b'\262\346*\010<= 10000'
  _IMPORTDATAREQUEST.fields_by_name['data']._options = None
  _IMPORTDATAREQUEST.fields_by_name['data']._serialized_options = b'\242\346*\005\030\200\200\200\010'
  _IMPORTPROGRESS._serialized_start=163
  _IMPORTPROGRESS._serialized_end=401
  _IMPORTPROGRESS_PROGRESS._serialized_start=182
  _IMPORTPROGRESS_PROGRESS._serialized_end=401
  _IMPORTITEMPROGRESS._serialized_start=404
  _IMPORTITEMPROGRESS._serialized_end=564
  _IMPORTFROMS3SETTINGS._serialized_start=567
  _IMPORTFROMS3SETTINGS._serialized_end=1458
  _IMPORTFROMS3SETTINGS_ITEM._serialized_start=1173
  _IMPORTFROMS3SETTINGS_ITEM._serialized_end=1263
  _IMPORTFROMS3SETTINGS_SCHEME._serialized_start=1265
  _IMPORTFROMS3SETTINGS_SCHEME._serialized_end=1311
  _IMPORTFROMS3SETTINGS_INDEXFILLINGMODE._serialized_start=1314
  _IMPORTFROMS3SETTINGS_INDEXFILLINGMODE._serialized_end=1458
  _IMPORTFROMS3RESULT._serialized_start=1460
  _IMPORTFROMS3RESULT._serialized_end=1480
  _IMPORTFROMS3METADATA._serialized_start=1483
  _IMPORTFROMS3METADATA._serialized_end=1668
  _IMPORTFROMS3REQUEST._serialized_start=1671
  _IMPORTFROMS3REQUEST._serialized_end=1809
  _IMPORTFROMS3RESPONSE._serialized_start=1811
  _IMPORTFROMS3RESPONSE._serialized_end=1879
  _IMPORTFROMFSSETTINGS._serialized_start=1882
  _IMPORTFROMFSSETTINGS._serialized_end=2257
  _IMPORTFROMFSSETTINGS_ITEM._serialized_start=2204
  _IMPORTFROMFSSETTINGS_ITEM._serialized_end=2257
  _IMPORTFROMFSRESULT._serialized_start=2259
  _IMPORTFROMFSRESULT._serialized_end=2279
  _IMPORTFROMFSMETADATA._serialized_start=2282
  _IMPORTFROMFSMETADATA._serialized_end=2467
  _IMPORTFROMFSREQUEST._serialized_start=2470
  _IMPORTFROMFSREQUEST._serialized_end=2608
  _IMPORTFROMFSRESPONSE._serialized_start=2610
  _IMPORTFROMFSRESPONSE._serialized_end=2678
  _LISTOBJECTSINS3EXPORTSETTINGS._serialized_start=2681
  _LISTOBJECTSINS3EXPORTSETTINGS._serialized_end=3133
  _LISTOBJECTSINS3EXPORTSETTINGS_ITEM._serialized_start=3113
  _LISTOBJECTSINS3EXPORTSETTINGS_ITEM._serialized_end=3133
  _LISTOBJECTSINS3EXPORTRESULT._serialized_start=3136
  _LISTOBJECTSINS3EXPORTRESULT._serialized_end=3289
  _LISTOBJECTSINS3EXPORTRESULT_ITEM._serialized_start=3253
  _LISTOBJECTSINS3EXPORTRESULT_ITEM._serialized_end=3289
  _LISTOBJECTSINS3EXPORTREQUEST._serialized_start=3292
  _LISTOBJECTSINS3EXPORTREQUEST._serialized_end=3501
  _LISTOBJECTSINS3EXPORTRESPONSE._serialized_start=3503
  _LISTOBJECTSINS3EXPORTRESPONSE._serialized_end=3580
  _LISTOBJECTSINFSEXPORTSETTINGS._serialized_start=3583
  _LISTOBJECTSINFSEXPORTSETTINGS._serialized_end=3837
  _LISTOBJECTSINFSEXPORTSETTINGS_ITEM._serialized_start=3113
  _LISTOBJECTSINFSEXPORTSETTINGS_ITEM._serialized_end=3133
  _LISTOBJECTSINFSEXPORTRESULT._serialized_start=3840
  _LISTOBJECTSINFSEXPORTRESULT._serialized_end=3997
  _LISTOBJECTSINFSEXPORTRESULT_ITEM._serialized_start=3957
  _LISTOBJECTSINFSEXPORTRESULT_ITEM._serialized_end=3997
  _LISTOBJECTSINFSEXPORTREQUEST._serialized_start=4000
  _LISTOBJECTSINFSEXPORTREQUEST._serialized_end=4209
  _LISTOBJECTSINFSEXPORTRESPONSE._serialized_start=4211
  _LISTOBJECTSINFSEXPORTRESPONSE._serialized_end=4288
  _YDBDUMPFORMAT._serialized_start=4290
  _YDBDUMPFORMAT._serialized_end=4322
  _IMPORTDATARESULT._serialized_start=4324
  _IMPORTDATARESULT._serialized_end=4342
  _IMPORTDATAREQUEST._serialized_start=4345
  _IMPORTDATAREQUEST._serialized_end=4519
  _IMPORTDATARESPONSE._serialized_start=4521
  _IMPORTDATARESPONSE._serialized_end=4587
# @@protoc_insertion_point(module_scope)



from protos import ydb_issue_message_pb2 as _ydb_issue_message_pb2
from protos import ydb_value_pb2 as _ydb_value_pb2
from protos import ydb_status_codes_pb2 as _ydb_status_codes_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ListingRequest(_message.Message):
    __slots__ = ("table_name", "key_prefix", "path_column_prefix", "path_column_delimiter", "continuation_token", "start_after_key_suffix", "max_keys", "columns_to_return", "matching_filter")
    class EMatchType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        EQUAL: _ClassVar[ListingRequest.EMatchType]
        NOT_EQUAL: _ClassVar[ListingRequest.EMatchType]
    EQUAL: ListingRequest.EMatchType
    NOT_EQUAL: ListingRequest.EMatchType
    TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    KEY_PREFIX_FIELD_NUMBER: _ClassVar[int]
    PATH_COLUMN_PREFIX_FIELD_NUMBER: _ClassVar[int]
    PATH_COLUMN_DELIMITER_FIELD_NUMBER: _ClassVar[int]
    CONTINUATION_TOKEN_FIELD_NUMBER: _ClassVar[int]
    START_AFTER_KEY_SUFFIX_FIELD_NUMBER: _ClassVar[int]
    MAX_KEYS_FIELD_NUMBER: _ClassVar[int]
    COLUMNS_TO_RETURN_FIELD_NUMBER: _ClassVar[int]
    MATCHING_FILTER_FIELD_NUMBER: _ClassVar[int]
    table_name: str
    key_prefix: _ydb_value_pb2.TypedValue
    path_column_prefix: str
    path_column_delimiter: str
    continuation_token: bytes
    start_after_key_suffix: _ydb_value_pb2.TypedValue
    max_keys: int
    columns_to_return: _containers.RepeatedScalarFieldContainer[str]
    matching_filter: _ydb_value_pb2.TypedValue
    def __init__(self, table_name: _Optional[str] = ..., key_prefix: _Optional[_Union[_ydb_value_pb2.TypedValue, _Mapping]] = ..., path_column_prefix: _Optional[str] = ..., path_column_delimiter: _Optional[str] = ..., continuation_token: _Optional[bytes] = ..., start_after_key_suffix: _Optional[_Union[_ydb_value_pb2.TypedValue, _Mapping]] = ..., max_keys: _Optional[int] = ..., columns_to_return: _Optional[_Iterable[str]] = ..., matching_filter: _Optional[_Union[_ydb_value_pb2.TypedValue, _Mapping]] = ...) -> None: ...

class ListingResponse(_message.Message):
    __slots__ = ("status", "issues", "common_prefixes", "contents", "is_truncated", "next_continuation_token")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ISSUES_FIELD_NUMBER: _ClassVar[int]
    COMMON_PREFIXES_FIELD_NUMBER: _ClassVar[int]
    CONTENTS_FIELD_NUMBER: _ClassVar[int]
    IS_TRUNCATED_FIELD_NUMBER: _ClassVar[int]
    NEXT_CONTINUATION_TOKEN_FIELD_NUMBER: _ClassVar[int]
    status: _ydb_status_codes_pb2.StatusIds.StatusCode
    issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
    common_prefixes: _containers.RepeatedScalarFieldContainer[str]
    contents: _ydb_value_pb2.ResultSet
    is_truncated: bool
    next_continuation_token: bytes
    def __init__(self, status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ..., common_prefixes: _Optional[_Iterable[str]] = ..., contents: _Optional[_Union[_ydb_value_pb2.ResultSet, _Mapping]] = ..., is_truncated: bool = ..., next_continuation_token: _Optional[bytes] = ...) -> None: ...



__all__ = [
    "CoordinationClient",
    "NodeConfig",
    "ConsistencyMode",
    "RateLimiterCountersMode",
    "DescribeResult",
    "CreateSemaphoreResult",
    "DescribeLockResult",
]

from .client import CoordinationClient


from .._grpc.grpcwrapper.ydb_coordination_public_types import (
    NodeConfig,
    ConsistencyMode,
    RateLimiterCountersMode,
    DescribeResult,
    CreateSemaphoreResult,
    DescribeLockResult,
)
